package com.xzzn.ems.mapper;

import java.util.List;
import com.xzzn.ems.domain.EmsStrategyCurve;
import org.apache.ibatis.annotations.Param;

/**
 * 策曲线Mapper接口
 *
 * @author xzzn
 * @date 2025-07-11
 */
public interface EmsStrategyCurveMapper
{
    /**
     * 查询策曲线
     *
     * @param id 策曲线主键
     * @return 策曲线
     */
    public EmsStrategyCurve selectEmsStrategyCurveById(Long id);

    /**
     * 查询策曲线列表
     *
     * @param emsStrategyCurve 策曲线
     * @return 策曲线集合
     */
    public List<EmsStrategyCurve> selectEmsStrategyCurveList(EmsStrategyCurve emsStrategyCurve);

    /**
     * 新增策曲线
     *
     * @param emsStrategyCurve 策曲线
     * @return 结果
     */
    public int insertEmsStrategyCurve(EmsStrategyCurve emsStrategyCurve);

    /**
     * 修改策曲线
     *
     * @param emsStrategyCurve 策曲线
     * @return 结果
     */
    public int updateEmsStrategyCurve(EmsStrategyCurve emsStrategyCurve);

    /**
     * 删除策曲线
     *
     * @param id 策曲线主键
     * @return 结果
     */
    public int deleteEmsStrategyCurveById(Long id);

    /**
     * 批量删除策曲线
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteEmsStrategyCurveByIds(Long[] ids);

    /**
     * 根据模板id获取曲线图数据
     * @param templateId
     * @return
     */
    public List<EmsStrategyCurve> getTemplateCurve(String templateId);

    public void physicalDeleteCurve(@Param("strategyId")Long strategyId,@Param("siteId")String siteId);
    // 根据模版id 删除推送的曲线图数据
    public void physicalDeleteByTemplateId(String templateId);
}
